@@ -1,7 +1,7 @@
 from mps_ledger_lib.ledger_utils.py_enum import PyEnumMixin
 
 
-class Type(PyEnumMixin):
+class LedgerType(PyEnumMixin):
     ORDER = 1
     FINE = 2
     ONEOFF = 3
